@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/ce_parser.h,v 1.4 2004/07/19 17:41:04 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/ce_parser.h,v 1.5 2004/07/27 14:55:17 richb Exp $
  *
  *  Copyright (C) 2004 Sami Pietila
  *
@@ -48,11 +48,13 @@ int ce_udf_parse(char *expression);
 static inline char *
 ce_strndup(char *str, int len)
 {
+    char *dup;
+
     if (len < 1) {
         return(NULL); 
     }
 
-    char *dup = malloc(len+1);
+    dup = malloc(len+1);
     memset(dup, 0, len+1);
     strncpy(dup, str, len);
 
