@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.33 2004/02/26 16:46:51 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.39 2004/09/16 22:20:58 richb Exp $
  *
  *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -109,15 +109,6 @@ get_int_resource(enum res_type rtype, int *intval)
 }
 
 
-/* Get keyboard equivalent from first character of localised string. */
-
-void
-get_key_val(int *val, char *str)
-{
-    *val = str[0];
-}
-
-
 /* Return the radix character. For most locales, this is a period. 
  * If nl_langinfo(RADIXCHAR) returns an empty string, return ",".
  */
@@ -161,10 +152,10 @@ get_options(int argc, char *argv[])      /* Extract command line options. */
                     INC;
                     getparam(next, argv, _("-a needs accuracy value"));
                     v->accuracy = atoi(next);
-                    if (v->accuracy < 0 || v->accuracy > 9) {
+                    if (v->accuracy < 0 || v->accuracy > MAXACC) {
                         FPRINTF(stderr, 
-                                _("%s: accuracy should be in the range 0-9\n"),
-                                v->progname);
+                                _("%s: accuracy should be in the range 0-%d\n"),
+                                v->progname, MAXACC);
                         v->accuracy = 9;
                     }
                     break;
@@ -316,9 +307,9 @@ read_resources()    /* Read all possible resources from the database. */
 
     if (get_int_resource(R_ACCURACY, &intval)) {
         v->accuracy = intval;
-        if (v->accuracy < 0 || v->accuracy > 9) {
-            FPRINTF(stderr, _("%s: accuracy should be in the range 0-9\n"), 
-                    v->progname);
+        if (v->accuracy < 0 || v->accuracy > MAXACC) {
+            FPRINTF(stderr, _("%s: accuracy should be in the range 0-%d\n"), 
+                    v->progname, MAXACC);
             v->accuracy = 9;
         }
     }
@@ -382,6 +373,24 @@ read_resources()    /* Read all possible resources from the database. */
         }
     }
 
+    /* Set expression (arithmetic precedence) mode as default. */
+    v->syntax = exprs;
+
+    if (get_str_resource(R_SYNTAX, str)) {
+      for (i = 0; i < MAXSYNTAX; i++) {
+	if (EQUAL(str, Rsstr[i])) {
+	  break;
+	}
+      }
+      
+      if (i == MAXSYNTAX) {
+	FPRINTF(stderr, _("%s: invalid syntax mode [%s]\n"), 
+		v->progname, str);
+      } else {
+	v->syntax = i;
+      }
+    }
+
     if (get_bool_resource(R_REGS, &boolval)) {
         v->rstate = boolval;
     }
@@ -393,6 +402,7 @@ read_resources()    /* Read all possible resources from the database. */
     if (get_bool_resource(R_TSEP, &boolval)) {
         v->show_tsep = boolval;
     }
+
 }
 
 
